/*******************************************************************************

Author : Mauro Laurenti
Version : 1.0
Created on Date : 02/02/2013
Last update     : 02/02/2013

CopyRight 2006-2013 all rights are reserved

********************************************************
SOFTWARE LICENSE AGREEMENT
********************************************************

The usage of the supplied software imply the acceptance of the following license.

The software supplied herewith by Mauro Laurenti (the Author)
is intended for use solely and exclusively on Microchip PIC Microcontroller (registered mark).
The software is owned by the Author, and is protected under applicable copyright laws.
All rights are reserved.
Any use in violation of the foregoing restrictions may subject the
user to criminal sanctions under applicable laws (Italian or International ones), as well as to
civil liability for the breach of the terms and conditions of this license.
Commercial use is forbidden without a written acknowledgment with the Author.
Personal or educational use is allowed if the application containing the following
software doesn't aim to commercial use or monetary earning of any kind.

THIS SOFTWARE IS PROVIDED IN AN "AS IS" CONDITION. NO WARRANTIES,
WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE AUTHOR SHALL NOT,
IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************
PURPOSES
********************************************************

This file contains all the configuration words needed for the PIC18F4550.
It can be easily adapted to other PICs according to the available configurations.

******  WARNING ******

The configurations must be changed to reflect the application needs!

//*****************************************************************************/


#ifndef PIC18F4550_H
#define PIC18F4550_H

#ifdef __XC8
#include <xc.h>
#endif

//******************************************************************************
// Register: CONFIG1L @ 0x300000
//******************************************************************************

// System Clock Postscaler Selection bits
//OSC2_PLL3	[Primary Oscillator Src: /2][96 MHz PLL Src: /3]
//OSC4_PLL6	[Primary Oscillator Src: /4][96 MHz PLL Src: /6]
//OSC3_PLL4	[Primary Oscillator Src: /3][96 MHz PLL Src: /4]
//OSC1_PLL2	[Primary Oscillator Src: /1][96 MHz PLL Src: /2]
#pragma config CPUDIV =	OSC1_PLL2

//PLL Prescaler Selection bits
//1	No prescale (4 MHz oscillator input drives PLL directly)
//5	Divide by 5 (20 MHz oscillator input)
//12	Divide by 12 (48 MHz oscillator input)
//2	Divide by 2 (8 MHz oscillator input)
//6	Divide by 6 (24 MHz oscillator input)
//3	Divide by 3 (12 MHz oscillator input)
//10	Divide by 10 (40 MHz oscillator input)
//4	Divide by 4 (16 MHz oscillator input)
#pragma config PLLDIV =	1

//USB Clock Selection bit (used in Full-Speed USB mode only; UCFG:FSEN = 1)
//1	USB clock source comes directly from the primary oscillator block with no postscale
//2	USB clock source comes from the 96 MHz PLL divided by 2
#pragma config USBDIV =	2


//******************************************************************************
// Register: CONFIG1H @ 0x300001
//******************************************************************************

//Internal/External Oscillator Switchover bit
//OFF	Oscillator Switchover mode disabled
//ON	Oscillator Switchover mode enabled
#pragma config IESO = OFF

//Oscillator Selection bits
//INTOSC_EC	Internal oscillator, CLKO function on RA6, EC used by USB (INTCKO)
//ECPLLIO_EC	EC oscillator, PLL enabled, port function on RA6 (ECPIO)
//XT_XT         XT oscillator (XT)
//INTOSC_HS	Internal oscillator, HS oscillator used by USB (INTHS)
//ECPLL_EC	EC oscillator, PLL enabled, CLKO function on RA6 (ECPLL)
//INTOSC_XT	Internal oscillator, XT used by USB (INTXT)
//EC_EC         EC oscillator, CLKO function on RA6 (EC)
//ECIO_EC       EC oscillator, port function on RA6 (ECIO)
//XTPLL_XT	XT oscillator, PLL enabled (XTPLL)
//HSPLL_HS	HS oscillator, PLL enabled (HSPLL)
//HS            HS oscillator (HS)
//INTOSCIO_EC	Internal oscillator, port function on RA6, EC used by USB (INTIO)
#pragma config FOSC =	HS

//Fail-Safe Clock Monitor Enable bit
//OFF	Fail-Safe Clock Monitor disabled
//ON	Fail-Safe Clock Monitor enabled

#pragma config FCMEN = OFF

//******************************************************************************
// Register: CONFIG2L @ 0x300002
//******************************************************************************

////USB Voltage Regulator Enable bit
//OFF	USB voltage regulator disabled
//ON	USB voltage regulator enabled
#pragma config VREGEN = OFF

//Brown-out Reset Enable bits
//SOFT	Brown-out Reset enabled and controlled by software (SBOREN is enabled)
//OFF	Brown-out Reset disabled in hardware and software
//ON	Brown-out Reset enabled in hardware only (SBOREN is disabled)
//ON_ACTIVE	Brown-out Reset enabled in hardware only and disabled in Sleep mode (SBOREN is disabled)
#pragma config BOR = OFF

//Brown-out Reset Voltage bits
//1
//2
//3	Minimum setting
//0	Maximum setting
#pragma config BORV = 0

//Power-up Timer Enable bit
//OFF	PWRT disabled
//ON	PWRT enabled
#pragma config PWRT = ON


//******************************************************************************
// Register: CCONFIG2H @ 0x300003
//******************************************************************************

//Watchdog Timer Postscale Select bits
//8	1:8
//1	1:1
//32768	1:32768
//1024	1:1024
//2	1:2
//32	1:32
//16	1:16
//16384	1:16384
//128	1:128
//4096	1:4096
//64	1:64
//8192	1:8192
//2048	1:2048
//512	1:512
//256	1:256
//4	1:4
#pragma config WDTPS = 1

//Watchdog Timer Enable bit
//OFF	WDT disabled (control is placed on the SWDTEN bit)
//ON	WDT enabled
#pragma config WDT = OFF


//******************************************************************************
// Register: CONFIG3H @ 0x300005
//******************************************************************************

//CCP2 MUX bit
//OFF	CCP2 input/output is multiplexed with RB3
//ON	CCP2 input/output is multiplexed with RC1
#pragma config CCP2MX =	OFF

//PORTB A/D Enable bit
//OFF	PORTB<4:0> pins are configured as digital I/O on Reset
//ON	PORTB<4:0> pins are configured as analog input channels on Reset
#pragma config PBADEN =	OFF

//Low-Power Timer 1 Oscillator Enable bit
//OFF	Timer1 configured for higher power operation
//ON	Timer1 configured for low-power operation
#pragma config LPT1OSC = OFF

//MCLR Pin Enable bit
//OFF	RE3 input pin enabled; MCLR pin disabled
//ON	MCLR pin enabled; RE3 input pin disabled
#pragma config MCLRE = ON


//******************************************************************************
// Register: CONFIG4L @ 0x300006
//******************************************************************************

//Background Debugger Enable bit
//OFF	Background debugger disabled, RB6 and RB7 configured as general purpose I/O pins
//ON	Background debugger enabled, RB6 and RB7 are dedicated to In-Circuit Debug
#pragma config DEBUG = OFF

//Stack Full/Underflow Reset Enable bit
//OFF	Stack full/underflow will not cause Reset
//ON	Stack full/underflow will cause Reset
#pragma config STVREN =	ON

//Dedicated In-Circuit Debug/Programming Port (ICPORT) Enable bit
//OFF	ICPORT disabled
//ON	ICPORT enabled
#pragma config ICPRT =	OFF

//Extended Instruction Set Enable bit
//OFF	Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
//ON	Instruction set extension and Indexed Addressing mode enabled
#pragma config XINST =	OFF

//Single-Supply ICSP Enable bit
//OFF	Single-Supply ICSP disabled
//ON	Single-Supply ICSP enabled
#pragma config LVP = OFF


//******************************************************************************
// Register: CONFIG5L @ 0x300008
//******************************************************************************

//Code Protection bit
//OFF	Block 0 (000800-001FFFh) is not code-protected
//ON	Block 0 (000800-001FFFh) is code-protected
#pragma config CP0 = OFF


//Code Protection bit
//OFF	Block 1 (002000-003FFFh) is not code-protected
//ON	Block 1 (002000-003FFFh) is code-protected
#pragma config CP1 = OFF

//Code Protection bit
//OFF	Block 2 (004000-005FFFh) is not code-protected
//ON	Block 2 (004000-005FFFh) is code-protected
#pragma config CP2 = OFF

//Code Protection bit
//OFF	Block 3 (006000-007FFFh) is not code-protected
//ON	Block 3 (006000-007FFFh) is code-protected
#pragma config CP3 = OFF


//******************************************************************************
// Register: CONFIG5H @ 0x300009
//******************************************************************************

//Data EEPROM Code Protection bit
//OFF	Data EEPROM is not code-protected
//ON	Data EEPROM is code-protected
#pragma config CPD = OFF

//Boot Block Code Protection bit
//OFF	Boot block (000000-0007FFh) is not code-protected
//ON	Boot block (000000-0007FFh) is code-protected
#pragma config CPB = OFF


//******************************************************************************
// Register: CONFIG6L @ 0x30000A
//******************************************************************************

//Write Protection bit
//OFF	Block 0 (000800-001FFFh) is not write-protected
//ON	Block 0 (000800-001FFFh) is write-protected
#pragma config WRT0 = OFF

//Write Protection bit
//OFF	Block 1 (002000-003FFFh) is not write-protected
//ON	Block 1 (002000-003FFFh) is write-protected
#pragma config WRT1 = OFF

//Write Protection bit
//OFF	Block 2 (004000-005FFFh) is not write-protected
//ON	Block 2 (004000-005FFFh) is write-protected
#pragma config WRT2 = OFF

//Write Protection bit
//OFF	Block 3 (006000-007FFFh) is not write-protected
//ON	Block 3 (006000-007FFFh) is write-protected
#pragma config WRT3 = OFF


//******************************************************************************
// Register: CONFIG6H @ 0x30000B
//******************************************************************************

//Boot Block Write Protection bit
//OFF	Boot block (000000-0007FFh) is not write-protected
//ON	Boot block (000000-0007FFh) is write-protected
#pragma config WRTB = OFF

//Configuration Register Write Protection bit
//OFF	Configuration registers (300000-3000FFh) are not write-protected
//ON	Configuration registers (300000-3000FFh) are write-protected
#pragma config WRTC = OFF

//Data EEPROM Write Protection bit
//OFF	Data EEPROM is not write-protected
//ON	Data EEPROM is write-protected
#pragma config WRTD = OFF


//******************************************************************************
// Register: CONFIG7L @ 0x30000C
//******************************************************************************

//Table Read Protection bit
//OFF	Block 0 (000800-001FFFh) is not protected from table reads executed in other blocks
//ON	Block 0 (000800-001FFFh) is protected from table reads executed in other blocks
#pragma config EBTR0 = OFF

//Table Read Protection bit
//OFF	Block 1 (002000-003FFFh) is not protected from table reads executed in other blocks
//ON	Block 1 (002000-003FFFh) is protected from table reads executed in other blocks
#pragma config EBTR1 = OFF

//Table Read Protection bit
//OFF	Block 2 (004000-005FFFh) is not protected from table reads executed in other blocks
//ON	Block 2 (004000-005FFFh) is protected from table reads executed in other blocks
#pragma config EBTR2 = OFF

//Table Read Protection bit
//OFF	Block 3 (006000-007FFFh) is not protected from table reads executed in other blocks
//ON	Block 3 (006000-007FFFh) is protected from table reads executed in other blocks
#pragma config EBTR3 = OFF


//******************************************************************************
// Register: CONFIG7H @ 0x30000D
//******************************************************************************

//Boot Block Table Read Protection bit
//OFF	Boot block (000000-0007FFh) is not protected from table reads executed in other blocks
//ON	Boot block (000000-0007FFh) is protected from table reads executed in other blocks
#pragma config EBTRB = OFF
   

#endif